@@ -26,6 +26,10 @@
 #include <QPixmap>
 #include <QUrl>
 
+#include "PlatformBackends/ImageGrabber.h"
+
+class QTemporaryDir;
+
 class ExportManager : public QObject
 {
     Q_OBJECT
@@ -50,12 +54,20 @@ class ExportManager : public QObject
 
     Q_PROPERTY(QString saveLocation READ saveLocation WRITE setSaveLocation NOTIFY saveLocationChanged)
     Q_PROPERTY(QPixmap pixmap READ pixmap WRITE setPixmap NOTIFY pixmapChanged)
+    Q_PROPERTY(QString windowTitle READ windowTitle WRITE setWindowTitle)
+    Q_PROPERTY(ImageGrabber::GrabMode grabMode READ grabMode WRITE setGrabMode)
 
     void setSaveLocation(const QString &location);
     QString saveLocation() const;
+    QUrl lastSavePath() const;
+    bool isFileExists(const QUrl &url) const;
     void setPixmap(const QPixmap &pixmap);
     QPixmap pixmap() const;
     QString pixmapDataUri() const;
+    void setWindowTitle(const QString &windowTitle);
+    QString windowTitle() const;
+    ImageGrabber::GrabMode grabMode() const;
+    void setGrabMode(const ImageGrabber::GrabMode &grabMode);
 
     signals:
 
@@ -63,30 +75,39 @@ class ExportManager : public QObject
     void saveLocationChanged(const QString &location);
     void pixmapChanged(const QPixmap &pixmap);
     void imageSaved(const QUrl &savedAt);
+    void forceNotify(const QUrl &savedAt);
 
     public slots:
 
     QUrl getAutosaveFilename();
-    QUrl tempSave(const QString &mimetype = "png");
+    QUrl tempSave(const QString &mimetype = QStringLiteral("png"));
 
-    void doSave(const QUrl &url = QUrl());
-    void doSaveAs(QWidget *parentWindow = 0);
+    void doSave(const QUrl &url = QUrl(), bool notify = false);
+    bool doSaveAs(QWidget *parentWindow = 0, bool notify = false);
     void doCopyToClipboard();
     void doPrint(QPrinter *printer);
 
     private:
 
+    QString truncatedFilename(const QString &filename);
     QString makeAutosaveFilename();
-    QString autoIncrementFilename(const QString &baseName, const QString &extension);
+    using FileNameAlreadyUsedCheck = bool (ExportManager::*)(const QUrl&) const;
+    QString autoIncrementFilename(const QString &baseName, const QString &extension,
+                                  FileNameAlreadyUsedCheck isFileNameUsed);
     QString makeSaveMimetype(const QUrl &url);
     bool writeImage(QIODevice *device, const QByteArray &format);
     bool save(const QUrl &url);
     bool localSave(const QUrl &url, const QString &mimetype);
     bool remoteSave(const QUrl &url, const QString &mimetype);
-    bool isFileExists(const QUrl &url);
+    bool isTempFileAlreadyUsed(const QUrl &url) const;
 
     QPixmap mSavePixmap;
+    QUrl mLastSavePath;
     QUrl mTempFile;
+    QTemporaryDir *mTempDir;
+    QList<QUrl> mUsedTempFileNames;
+    QString mWindowTitle;
+    ImageGrabber::GrabMode mGrabMode;
 };
 
 #endif // EXPORTMANAGER_H
