@@ -31,10 +31,15 @@
 
 #include <KLocalizedString>
 
+namespace SpectacleImage {
+    static const int SHADOW_RADIUS = 5;
+}
+
 class KSImageWidget : public QLabel
 {
     Q_OBJECT
 
+
     public:
 
     explicit KSImageWidget(QWidget *parent = 0);
